module Pages.Services exposing (page)

import Config.Identity as ID exposing (..)
import Config.Theme as T exposing (..)
import Element exposing (..)
import Element.Background as B
import Element.Font as F
import Element.Region exposing (description)
import View exposing (View)


page : View msg
page =
    { title = servicesName
    , attributes = [ F.family [ spartanFont ] ]
    , element = servicesContainer
    }


servicesContainer : Element msg
servicesContainer =
    topLevelContainer servicesList


servicesList : Element msg
servicesList =
    column
        [ spacing 20
        , centerX
        , centerY
        ]
        services


services : List (Element msg)
services =
    let
        servicesImageFormat : List (Attribute msg)
        servicesImageFormat =
            [ width <| px 100
            , alignTop
            ]
    in
    [ column
        [ spacing 40 ]
        [ row [ imageSpacer ]
            [ image servicesImageFormat
                { src = "debate.png"
                , description = "debate logo"
                }
            , column paragraphColumnFormat
                [ row [ spacing 8 ]
                    [ newTabLink titleFormat
                        { url = "https://the-nutrivore.social/"
                        , label = text "DEBATE COACHING"
                        }
                    , paragraph [ F.color colourTheme.nonHighlightedText ] [ text "$60/hr" ]
                    ]
                , paragraph paragraphFormat [ text "Participate in a structured course consisting of five one-hour modules, covering critical thinking, debate strategy, propositional logic, and more. Throughout the course you will receive both personalized and generalizable advice on how to improve your debate performance." ]
                ]
            ]
        , row [ imageSpacer ]
            [ image servicesImageFormat
                { src = "analysis.png"
                , description = "analysis logo"
                }
            , column paragraphColumnFormat
                [ row [ spacing 8 ]
                    [ newTabLink titleFormat
                        { url = "https://the-nutrivore.social/"
                        , label = text "DEBATE ANALYSIS"
                        }
                    , paragraph [ F.color colourTheme.nonHighlightedText ] [ text "$80/hr" ]
                    ]
                , paragraph paragraphFormat [ text "Participate in focused one-hour sessions wherein your own recorded debates are analyzed for constructive feedback and advice to help you improve as a debater. You may also participate in mock debates, staged debates, and other exercises to help you get more comfortable with debate and verbal confrontation." ]
                ]
            ]
        , row [ imageSpacer ]
            [ image servicesImageFormat
                { src = "nutrition.png"
                , description = "analysis logo"
                }
            , column paragraphColumnFormat
                [ row [ spacing 8 ]
                    [ newTabLink titleFormat
                        { url = "https://the-nutrivore.social/"
                        , label = text "NUTRITION SCIENCE"
                        }
                    , paragraph [ F.color colourTheme.nonHighlightedText ] [ text "$40/hr" ]
                    ]
                , paragraph paragraphFormat [ text "Participate in a one-hour Q&A session specifically to inquire about nutrition science. Ask questions about research design, methodology, epistemology, and study interpretation. Also, by participating you will also gain access to nutrition science interpretation cheat-sheets that will streamline and simply the research appraisal process." ]
                ]
            ]
        , row [ imageSpacer ]
            [ image servicesImageFormat
                { src = "nixos.png"
                , description = "debate logo"
                }
            , column paragraphColumnFormat
                [ row [ spacing 8 ]
                    [ newTabLink titleFormat
                        { url = "https://the-nutrivore.social/"
                        , label = text "CUSTOM NIX BUILDS"
                        }
                    , paragraph [ F.color colourTheme.nonHighlightedText ] [ text "$40/hr" ]
                    ]
                , paragraph paragraphFormat [ text "NixOS has become popular in my community, with many people choosing to explore it over Windows, MacOS, and other Linux distributions. Naturally, as a consequence of this, I receive numerous requests for help regarding the Nix programming language and NixOS system configuration. So, to fast-track newcomers and to make my life a little bit easier for both of us, I'm offering to build custom NixOS configurations for interested clients." ]
                ]
            ]
        ]
    ]
